=====
Usage
=====

Start by importing Icarus Pressure Jump for NMR.

.. code-block:: python

  import icarus_nmr

Data Analysis
-------------------

The icarus analysis submodule allow easy and seamless access to the logged data from the pressure jump experiment. The instantiation of the Dataset class creates a link to a folder allowing easy access to the log file and traces.

The Dataset class has
log_header = None
log_data = None
log_length = 0
description = ''
trace_length
trace_lists

Instrumentation
-------------------
